pub fn provide_auth_context(initial: AuthSession) -> AuthContextExpand description
Provide AuthContext to the component tree and return it.
Most applications call this once near the root layout or router.
pub fn provide_auth_context(initial: AuthSession) -> AuthContextProvide AuthContext to the component tree and return it.
Most applications call this once near the root layout or router.