pub fn use_auth_state() -> Memo<AuthSession>Expand description
Reactive memo for the current AuthSession.
Use this when a component needs to branch on anonymous vs authenticated state.
pub fn use_auth_state() -> Memo<AuthSession>Reactive memo for the current AuthSession.
Use this when a component needs to branch on anonymous vs authenticated state.